# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import test_blacklist
from . import test_blacklist_mixin
from . import test_composer
from . import test_link
from . import test_mail_auto_blacklist
from . import test_mail_channel
from . import test_mailing_internals
from . import test_mass_mailing
from . import test_performance
